import { Box } from 'bumbag/Box';
import { Code } from 'bumbag/Code';
import { Text } from 'bumbag/Text';
import { styled, css, cssClass } from 'bumbag/styled';
import { theme, palette } from 'bumbag/utils';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5, _templateObject6, _templateObject7;
var Token = styled(Text)(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["\n  & {\n    ", ";\n  }\n"])), theme('HighlightedCode.Token.styles.base'));
var Pre = styled(Code)(_templateObject2 || (_templateObject2 = _taggedTemplateLiteralLoose(["\n  overflow-x: auto;\n\n  ", ";\n\n  & {\n    ", ";\n  }\n"])), function (props) {
  return !props.isBlock && css(_templateObject3 || (_templateObject3 = _taggedTemplateLiteralLoose(["\n      display: inline;\n    "])));
}, theme('HighlightedCode.Pre.styles.base'));
var Line = styled(Box)(_templateObject4 || (_templateObject4 = _taggedTemplateLiteralLoose(["\n  ", ";\n\n  & {\n    ", ";\n  }\n"])), function (props) {
  return !props.isBlock && css(_templateObject5 || (_templateObject5 = _taggedTemplateLiteralLoose(["\n      display: inline;\n    "])));
}, theme('HighlightedCode.Line.styles.base'));
var HighlightedCode = function HighlightedCode(styleProps) {
  return cssClass(_templateObject6 || (_templateObject6 = _taggedTemplateLiteralLoose(["\n  ", ";\n\n  & {\n    ", ";\n  };\n"])), styleProps.isBlock && css(_templateObject7 || (_templateObject7 = _taggedTemplateLiteralLoose(["\n      & {\n        ", ";\n      }\n    "])), theme('HighlightedCode.styles.block')(styleProps)), theme('HighlightedCode.styles.base')(styleProps));
};
var codeTheme = function codeTheme(styleProps) {
  return {
    default: {
      plain: {
        color: palette('text')(styleProps),
        backgroundColor: palette('white700')(styleProps)
      },
      styles: [{
        types: ['changed'],
        style: {
          color: palette('info')(styleProps)
        }
      }, {
        types: ['deleted'],
        style: {
          color: palette('danger')(styleProps)
        }
      }, {
        types: ['inserted', 'attr-name'],
        style: {
          color: palette('secondary')(styleProps)
        }
      }, {
        types: ['attr-value'],
        style: {
          color: palette('text')(styleProps)
        }
      }, {
        types: ['comment'],
        style: {
          color: palette('gray400')(styleProps)
        }
      }, {
        types: ['builtin', 'char', 'url'],
        style: {
          color: palette('secondary')(styleProps)
        }
      }, {
        types: ['string'],
        style: {
          color: palette('text')(styleProps)
        }
      }, {
        types: ['variable'],
        style: {
          color: palette('info')(styleProps)
        }
      }, {
        types: ['number'],
        style: {
          color: palette('info')(styleProps)
        }
      }, {
        // This was manually added after the auto-generation
        // so that punctuations are not italicised
        types: ['punctuation'],
        style: {
          color: palette('primary')(styleProps)
        }
      }, {
        types: ['function', 'selector', 'doctype'],
        style: {
          color: palette('secondary')(styleProps)
        }
      }, {
        types: ['class-name', 'maybe-class-name'],
        style: {
          color: palette('primary')(styleProps)
        }
      }, {
        types: ['tag'],
        style: {
          color: palette('primary')(styleProps)
        }
      }, {
        types: ['operator', 'property', 'keyword', 'namespace'],
        style: {
          color: palette('primary')(styleProps)
        }
      }, {
        types: ['boolean'],
        style: {
          color: palette('info')(styleProps)
        }
      }]
    },
    dark: {
      plain: {
        color: palette('white')(styleProps),
        backgroundColor: '#0e0c27'
      },
      styles: [{
        types: ['changed'],
        style: {
          color: palette('info')(styleProps)
        }
      }, {
        types: ['deleted'],
        style: {
          color: palette('danger')(styleProps)
        }
      }, {
        types: ['inserted', 'attr-name'],
        style: {
          color: palette('secondary300')(styleProps)
        }
      }, {
        types: ['attr-value'],
        style: {
          color: palette('white')(styleProps)
        }
      }, {
        types: ['comment'],
        style: {
          color: palette('gray400')(styleProps)
        }
      }, {
        types: ['builtin', 'char', 'url'],
        style: {
          color: palette('secondary300')(styleProps)
        }
      }, {
        types: ['string'],
        style: {
          color: palette('white')(styleProps)
        }
      }, {
        types: ['variable'],
        style: {
          color: palette('info')(styleProps)
        }
      }, {
        types: ['number'],
        style: {
          color: palette('white')(styleProps)
        }
      }, {
        // This was manually added after the auto-generation
        // so that punctuations are not italicised
        types: ['punctuation'],
        style: {
          color: palette('primary300')(styleProps)
        }
      }, {
        types: ['function', 'selector', 'doctype'],
        style: {
          color: palette('secondary300')(styleProps)
        }
      }, {
        types: ['class-name', 'maybe-class-name'],
        style: {
          color: palette('primary300')(styleProps)
        }
      }, {
        types: ['tag'],
        style: {
          color: palette('primary300')(styleProps)
        }
      }, {
        types: ['operator', 'property', 'keyword', 'namespace'],
        style: {
          color: palette('primary300')(styleProps)
        }
      }, {
        types: ['boolean'],
        style: {
          color: palette('white')(styleProps)
        }
      }]
    }
  };
};

var styles = /*#__PURE__*/Object.freeze({
  __proto__: null,
  Token: Token,
  Pre: Pre,
  Line: Line,
  HighlightedCode: HighlightedCode,
  codeTheme: codeTheme
});

export { HighlightedCode as H, Line as L, Pre as P, Token as T, _objectSpread2 as _, _extends as a, codeTheme as c, styles as s };
